@@ -5,12 +5,12 @@ Unstable experiments with NAFF.
 :license: MIT, see LICENSE for more details.
 """
 
-__version__ = "0.5.0"
+__version__ = "0.5.2"
 
 
 from .slash_commands import *
 from .slash_param import *
-from .speedup.install import install_naff_speedups
+from .speedup import install_naff_speedups
 
 __all__ = (
     "TansySlashCommandParameter",
